/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/

package org.fortiss.af3.rcp.application.advisors;

import java.util.HashSet;

import org.eclipse.swt.graphics.Point;
import org.eclipse.ui.IEditorReference;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.activities.IWorkbenchActivitySupport;
import org.eclipse.ui.application.ActionBarAdvisor;
import org.eclipse.ui.application.IActionBarConfigurer;
import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
import org.eclipse.ui.application.WorkbenchWindowAdvisor;
import org.fortiss.af3.exploration.ui.AF3ExplorationUIActivator;

/**
 * Workbench window advisor for AF3 RCP.
 * 
 * @author ratiu
 */
public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {

	/** Constructor. */
	public ApplicationWorkbenchWindowAdvisor(IWorkbenchWindowConfigurer configurer) {
		super(configurer);
	}

	/** {@inheritDoc} */
	@Override
	public ActionBarAdvisor createActionBarAdvisor(IActionBarConfigurer configurer) {
		return new ApplicationActionBarAdvisor(configurer);
	}

	/** {@inheritDoc} */
	@Override
	public void preWindowOpen() {
		IWorkbenchWindowConfigurer configurer = getWindowConfigurer();
		configurer.setInitialSize(new Point(800, 600));
		configurer.setShowCoolBar(true);
		configurer.setShowStatusLine(true);
		configurer.setShowMenuBar(true);
		configurer.setShowPerspectiveBar(true);
		configurer.setShowProgressIndicator(true);
	}

	/** {@inheritDoc} */
	@Override
	public void postWindowCreate() {
		IWorkbench wb = getWindowConfigurer().getWorkbenchConfigurer().getWorkbench();
		IWorkbenchActivitySupport activitySupport = wb.getActivitySupport();
		activitySupport.setEnabledActivityIds(new HashSet<String>());

		// Workaround for https://af3.fortiss.org/issues/2033 and
		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=386648
		for(IWorkbenchWindow ww : wb.getWorkbenchWindows()) {
			for(IWorkbenchPage wp : ww.getPages()) {
				for(IEditorReference ref : wp.getEditorReferences()) {
					if("org.eclipse.ui.internal.emptyEditorTab".equals(ref.getId())) {
						wp.closeEditors(new IEditorReference[] {ref}, false);
					}
				}
			}
		}
		// Register DSE perspective listener
		AF3ExplorationUIActivator.registerPerspectiveListener();
	}
}
